@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: attach.c,v 1.12 1998/11/10 21:02:18 roessler Exp $";
+static const char rcsid[]="$Id: attach.c,v 1.14 1998/11/15 09:42:00 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -256,7 +256,7 @@ int mutt_edit_attachment (BODY *a)
   else if (a->type == TYPETEXT)
   {
     /* On text, default to editor */
-    mutt_edit_file ((!Editor || strcmp ("builtin", Editor) == 0) ? 
+    mutt_edit_file ((!Editor || mutt_strcmp ("builtin", Editor) == 0) ? 
 		    NONULL(Visual) : NONULL(Editor), newfile);
   }
   else
@@ -284,10 +284,10 @@ int mutt_is_autoview (char *type)
 
   while (t)
   {
-    i = strlen (t->data) - 1;
+    i = mutt_strlen (t->data) - 1;
     if ((i > 0 && t->data[i-1] == '/' && t->data[i] == '*' && 
-	  strncasecmp (type, t->data, i) == 0) ||
-	  strcasecmp (type, t->data) == 0)
+	  mutt_strncasecmp (type, t->data, i) == 0) ||
+	  mutt_strcasecmp (type, t->data) == 0)
       return 1;
     t = t->next;
   }
@@ -359,7 +359,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag)
     if (rfc1524_expand_filename (entry->nametemplate, fname,
 				 tempfile, sizeof (tempfile)))
     {
-      if (fp == NULL && strcmp(tempfile, a->filename))
+      if (fp == NULL && mutt_strcmp(tempfile, a->filename))
       {
 	/* send case: the file is already there */
 	if (safe_symlink (a->filename, tempfile) == -1)
@@ -745,12 +745,9 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, char *path,
     m->length = st.st_size;
     m->encoding = ENC8BIT;
     m->offset = 0;
-    if (mutt_is_message_type(m->type, m->subtype))
-    {
-      saved_parts = m->parts;
-      saved_hdr = m->hdr;
-      m->parts = mutt_parse_messageRFC822 (s.fpin, m);
-    }
+    saved_parts = m->parts;
+    saved_hdr = m->hdr;
+    mutt_parse_part (s.fpin, m);
   }
   else
     s.fpin = fp;
@@ -859,8 +856,8 @@ int mutt_print_attachment (FILE *fp, BODY *a)
     return (1);
   }
 
-  if (!strcasecmp ("text/plain", a->subtype) ||
-      !strcasecmp ("application/postscript", a->subtype))
+  if (!mutt_strcasecmp ("text/plain", a->subtype) ||
+      !mutt_strcasecmp ("application/postscript", a->subtype))
   {
     return (mutt_pipe_attachment (fp, a, NONULL(PrintCmd), NULL));
   }
