@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: color.c,v 1.8 1998/11/09 11:15:28 roessler Exp $";
+static const char rcsid[]="$Id: color.c,v 1.9 1998/11/10 22:14:07 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -290,14 +290,14 @@ parse_color_name (const char *s, int *col, int *attr, int brite, BUFFER *err)
 {
   char *eptr;
 
-  if (strncasecmp (s, "bright", 6) == 0)
+  if (mutt_strncasecmp (s, "bright", 6) == 0)
   {
     *attr |= brite;
     s += 6;
   }
 
   /* allow aliases for xterm color resources */
-  if (strncasecmp (s, "color", 5) == 0)
+  if (mutt_strncasecmp (s, "color", 5) == 0)
   {
     s += 5;
     *col = strtol (s, &eptr, 10);
@@ -360,7 +360,7 @@ _mutt_parse_uncolor (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err,
     return (-1);
   }
 
-  if (strncmp (buf->data, "index", 5) != 0)
+  if (mutt_strncmp (buf->data, "index", 5) != 0)
   {
     snprintf (err->data, err->dsize,
 	      _("%s: command valid only for index object"), 
@@ -391,7 +391,7 @@ _mutt_parse_uncolor (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err,
   do
   {
     mutt_extract_token (buf, s, 0);
-    if (!strcmp ("*", buf->data))
+    if (!mutt_strcmp ("*", buf->data))
     {
       for (tmp = ColorIndexList; tmp; )
       {
@@ -407,7 +407,7 @@ _mutt_parse_uncolor (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err,
     {
       for (last = NULL, tmp = ColorIndexList; tmp; last = tmp, tmp = tmp->next)
       {
-	if (!strcmp (buf->data, tmp->pattern))
+	if (!mutt_strcmp (buf->data, tmp->pattern))
 	{
           if (!do_cache)
 	    do_cache = 1;
@@ -454,12 +454,12 @@ add_pattern (COLOR_LINE **top, const char *s, int sensitive,
   {
     if (sensitive)
     {
-      if (strcmp (s, tmp->pattern) == 0)
+      if (mutt_strcmp (s, tmp->pattern) == 0)
 	break;
     }
     else
     {
-      if (strcasecmp (s, tmp->pattern) == 0)
+      if (mutt_strcasecmp (s, tmp->pattern) == 0)
 	break;
     }
     tmp = tmp->next;
@@ -540,7 +540,7 @@ parse_object(BUFFER *buf, BUFFER *s, int *o, int *ql, BUFFER *err)
   }
   
   mutt_extract_token(buf, s, 0);
-  if(!strncmp(buf->data, "quoted", 6))
+  if(!mutt_strncmp(buf->data, "quoted", 6))
   {
     if(buf->data[6])
     {
@@ -614,17 +614,17 @@ parse_attr_spec(BUFFER *buf, BUFFER *s, int *fg, int *bg, int *attr, BUFFER *err
 
   mutt_extract_token (buf, s, 0);
 
-  if (strcasecmp ("bold", buf->data) == 0)
+  if (mutt_strcasecmp ("bold", buf->data) == 0)
     *attr |= A_BOLD;
-  else if (strcasecmp ("underline", buf->data) == 0)
+  else if (mutt_strcasecmp ("underline", buf->data) == 0)
     *attr |= A_UNDERLINE;
-  else if (strcasecmp ("none", buf->data) == 0)
+  else if (mutt_strcasecmp ("none", buf->data) == 0)
     *attr = A_NORMAL;
-  else if (strcasecmp ("reverse", buf->data) == 0)
+  else if (mutt_strcasecmp ("reverse", buf->data) == 0)
     *attr |= A_REVERSE;
-  else if (strcasecmp ("standout", buf->data) == 0)
+  else if (mutt_strcasecmp ("standout", buf->data) == 0)
     *attr |= A_STANDOUT;
-  else if (strcasecmp ("normal", buf->data) == 0)
+  else if (mutt_strcasecmp ("normal", buf->data) == 0)
     *attr = A_NORMAL; /* needs use = instead of |= to clear other bits */
   else
   {
