@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: compose.c,v 1.31 1998/11/10 20:05:53 roessler Exp $";
+static const char rcsid[]="$Id: compose.c,v 1.35 1998/11/18 22:56:57 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -191,8 +191,8 @@ static int pgp_send_menu (int bits, int *redraw)
 
       if(mutt_get_field (_("MIC algorithm: "), input_micalg, sizeof(input_micalg), 0) == 0)
       {
-	if(strcasecmp(input_micalg, "pgp-md5") && strcasecmp(input_micalg, "pgp-sha1")
-	   && strcasecmp(input_micalg, "pgp-rmd160"))
+	if(mutt_strcasecmp(input_micalg, "pgp-md5") && mutt_strcasecmp(input_micalg, "pgp-sha1")
+	   && mutt_strcasecmp(input_micalg, "pgp-rmd160"))
 	{
 	  mutt_error _("Unknown MIC algorithm, valid ones are: pgp-md5, pgp-sha1, pgp-rmd160");
 	}
@@ -383,7 +383,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
   int oldSort = Sort, oldSortAux = SortAux;
   struct stat st;
 
-  idx = mutt_gen_attach_list (msg->content, idx, &idxlen, &idxmax, 0, 1);
+  idx = mutt_gen_attach_list (msg->content, -1, idx, &idxlen, &idxmax, 0, 1);
 
   menu = mutt_new_menu ();
   menu->menu = MENU_COMPOSE;
@@ -446,7 +446,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	MAYBE_REDRAW (menu->redraw);
 	break;
       case OP_COMPOSE_EDIT_MESSAGE:
-	if (Editor && (strcmp ("builtin", Editor) != 0) && !option (OPTEDITHDRS))
+	if (Editor && (mutt_strcmp ("builtin", Editor) != 0) && !option (OPTEDITHDRS))
 	{
 	  mutt_edit_file (Editor, msg->content->filename);
 	  mutt_update_encoding (msg->content);
@@ -458,7 +458,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if (op == OP_COMPOSE_EDIT_HEADERS ||
 	    (op == OP_COMPOSE_EDIT_MESSAGE && option (OPTEDITHDRS)))
 	{
-	  mutt_edit_headers ((!Editor || strcmp ("builtin", Editor) == 0) ? NONULL(Visual) : NONULL(Editor),
+	  mutt_edit_headers ((!Editor || mutt_strcmp ("builtin", Editor) == 0) ? NONULL(Visual) : NONULL(Editor),
 			     msg->content->filename, msg, fcc, fcclen);
 	}
 	else
@@ -477,7 +477,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  for (i = 0; i < idxlen; i++)
 	    safe_free ((void **) &idx[i]);
 	  idxlen = 0;
-	  idx = mutt_gen_attach_list (msg->content, idx, &idxlen, &idxmax, 0, 1);
+	  idx = mutt_gen_attach_list (msg->content, -1, idx, &idxlen, &idxmax, 0, 1);
 	  menu->data = idx;
 	  menu->max = idxlen;
 	}
@@ -720,19 +720,26 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 		  idx[menu->current]->content->subtype);
 	if (mutt_get_field ("Content-Type: ", buf, sizeof (buf), 0) == 0 && buf[0])
 	{
-	  char *p = strchr (buf, '/');
+	  char *s;
+	  PARAMETER *par;
+	  BODY *b;
+	  
+	  b = idx[menu->current]->content;
+	  
+	  s  = b->filename;  par = b->parameter;
+	  b->filename  = NULL;  b->parameter = NULL;
+	  
+	  mutt_parse_content_type(buf, b);
 
-	  if (p)
-	  {
-	    *p++ = 0;
-	    if ((i = mutt_check_mime_type (buf)) != TYPEOTHER)
-	    {
-	      idx[menu->current]->content->type = i;
-	      safe_free ((void **) &idx[menu->current]->content->subtype);
-	      idx[menu->current]->content->subtype = safe_strdup (p);
-	      menu->redraw = REDRAW_CURRENT;
-	    }
-	  }
+	  safe_free((void **) &b->filename);
+	  b->filename =s;
+	  
+	  if ((s = mutt_get_parameter("charset", b->parameter)))
+	    mutt_set_parameter("charset", s, &par);
+
+	  /* ignore the other parameters for now */
+	  mutt_free_parameter(&b->parameter);
+	  b->parameter = par;
 	}
 	break;
 
@@ -743,23 +750,11 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	if (mutt_get_field ("Content-Transfer-Encoding: ", buf,
 					    sizeof (buf), 0) == 0 && buf[0])
 	{
-	  if ((i = mutt_check_encoding (buf)) != ENCOTHER)
+	  if ((i = mutt_check_encoding (buf)) != ENCOTHER && i != ENCUUENCODED)
 	  {
-#ifndef PERMIT_DEPRECATED_UUENCODED_MESSAGES
-	    if (i == ENCUUENCODED)
-	    {
-	      mutt_error _("Invalid encoding.");
-	      break;
-	    }
-#else
-	    if(i != ENCUUENCODED ||
-	      mutt_yesorno(_("This encoding is deprecated.  Really use it?"), 0) == M_YES)
-#endif
-	    {
-	      idx[menu->current]->content->encoding = i;
-	      menu->redraw = REDRAW_CURRENT;
-	      mutt_clear_error();
-	    }
+	    idx[menu->current]->content->encoding = i;
+	    menu->redraw = REDRAW_CURRENT;
+	    mutt_clear_error();
 	  }
 	  else
 	    mutt_error _("Invalid encoding.");
@@ -789,7 +784,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
       case OP_COMPOSE_EDIT_FILE:
 	CHECK_COUNT;
-	mutt_edit_file ((!Editor || strcmp ("builtin", Editor) == 0) ? NONULL(Visual) : NONULL(Editor),
+	mutt_edit_file ((!Editor || mutt_strcmp ("builtin", Editor) == 0) ? NONULL(Visual) : NONULL(Editor),
 			idx[menu->current]->content->filename);
 	mutt_update_encoding (idx[menu->current]->content);
 	menu->redraw = REDRAW_CURRENT;
