@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: copy.c,v 1.14 1998/11/10 21:02:21 roessler Exp $";
+static const char rcsid[]="$Id: copy.c,v 1.18 1998/11/15 09:34:16 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -36,8 +36,7 @@ static const char rcsid[]="$Id: copy.c,v 1.14 1998/11/10 21:02:21 roessler Exp $
 
 extern char MimeSpecials[];
 
-static int copy_delete_attach (HEADER *h, BODY *b, FILE *fpin, FILE *fpout,
-			       int update);
+static int copy_delete_attach (BODY *b, FILE *fpin, FILE *fpout, char *date);
 
 /* Ok, the only reason for not merging this with mutt_copy_header()
  * below is to avoid creating a HEADER structure in message_handler().
@@ -78,7 +77,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
       if (nl && buf[0] != ' ' && buf[0] != '\t')
       {
 	ignore = 1;
-	if (!from && strncmp ("From ", buf, 5) == 0)
+	if (!from && mutt_strncmp ("From ", buf, 5) == 0)
 	{
 	  if ((flags & CH_FROM) == 0)
 	    continue;
@@ -88,12 +87,12 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
 	  break; /* end of header */
 
 	if ((flags & (CH_UPDATE | CH_XMIT | CH_NOSTATUS)) &&
-	    (strncasecmp ("Status:", buf, 7) == 0 ||
-	     strncasecmp ("X-Status:", buf, 9) == 0))
+	    (mutt_strncasecmp ("Status:", buf, 7) == 0 ||
+	     mutt_strncasecmp ("X-Status:", buf, 9) == 0))
 	  continue;
-	if ((flags & (CH_UPDATE_LEN | CH_XMIT)) &&
-	    (strncasecmp ("Content-Length:", buf, 15) == 0 ||
-	     strncasecmp ("Lines:", buf, 6) == 0))
+	if ((flags & (CH_UPDATE_LEN | CH_XMIT | CH_NOLEN)) &&
+	    (mutt_strncasecmp ("Content-Length:", buf, 15) == 0 ||
+	     mutt_strncasecmp ("Lines:", buf, 6) == 0))
 	  continue;
 	ignore = 0;
       }
@@ -138,7 +137,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
     if (nl && buf[0] != ' ' && buf[0] != '\t')
     {
       ignore = 1;
-      if (!from && strncmp ("From ", buf, 5) == 0)
+      if (!from && mutt_strncmp ("From ", buf, 5) == 0)
       {
 	if ((flags & CH_FROM) == 0)
 	  continue;
@@ -152,18 +151,18 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
 	  !mutt_matches_ignore (buf, UnIgnore))
 	continue;
       if ((flags & (CH_UPDATE | CH_XMIT | CH_NOSTATUS)) &&
-	  (strncasecmp ("Status:", buf, 7) == 0 ||
-	   strncasecmp ("X-Status:", buf, 9) == 0))
+	  (mutt_strncasecmp ("Status:", buf, 7) == 0 ||
+	   mutt_strncasecmp ("X-Status:", buf, 9) == 0))
 	continue;
-      if ((flags & (CH_UPDATE_LEN | CH_XMIT)) &&
-	  (strncasecmp ("Content-Length:", buf, 15) == 0 ||
-	   strncasecmp ("Lines:", buf, 6) == 0))
+      if ((flags & (CH_UPDATE_LEN | CH_XMIT | CH_NOLEN)) &&
+	  (mutt_strncasecmp ("Content-Length:", buf, 15) == 0 ||
+	   mutt_strncasecmp ("Lines:", buf, 6) == 0))
 	continue;
       if ((flags & CH_MIME) &&
-	  ((strncasecmp ("content-", buf, 8) == 0 &&
-	    (strncasecmp ("transfer-encoding:", buf + 8, 18) == 0 ||
-	     strncasecmp ("type:", buf + 8, 5) == 0)) ||
-	   strncasecmp ("mime-version:", buf, 13) == 0))
+	  ((mutt_strncasecmp ("content-", buf, 8) == 0 &&
+	    (mutt_strncasecmp ("transfer-encoding:", buf + 8, 18) == 0 ||
+	     mutt_strncasecmp ("type:", buf + 8, 5) == 0)) ||
+	   mutt_strncasecmp ("mime-version:", buf, 13) == 0))
 	continue;
 
       /* Find x -- the array entry where this header is to be saved */
@@ -171,7 +170,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
       {
 	for (t = HeaderOrderList, x = 0 ; (t) ; t = t->next, x++)
 	{
-	  if (!strncasecmp (buf, t->data, strlen (t->data)))
+	  if (!mutt_strncasecmp (buf, t->data, mutt_strlen (t->data)))
 	  {
 	    dprint(2, (debugfile, "Reorder: %s matches %s", t->data, buf));
 	    break;
@@ -190,7 +189,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
       else
       {
 	safe_realloc ((void **) &headers[x],
-		      strlen (headers[x]) + strlen (buf) + sizeof (char));
+		      mutt_strlen (headers[x]) + mutt_strlen (buf) + sizeof (char));
 	strcat (headers[x], buf);
       }
     }
@@ -202,7 +201,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
     if (headers[x])
     {
       if (flags & CH_DECODE)
-	rfc2047_decode (headers[x], headers[x], strlen (headers[x]));
+	rfc2047_decode (headers[x], headers[x], mutt_strlen (headers[x]));
 
       /* We couldn't do the prefixing when reading because RFC 2047
        * decoding may have concatenated lines.
@@ -262,6 +261,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
  	CH_DECODE	RFC2047 header decoding
  	CH_FROM		retain the "From " message separator
  	CH_MIME		ignore MIME fields
+	CH_NOLEN	don't write Content-Length: and Lines:
  	CH_NONEWLINE	don't output a newline after the header
  	CH_NOSTATUS	ignore the Status: and X-Status:
  	CH_PREFIX	quote header with $indent_str
@@ -341,7 +341,8 @@ mutt_copy_header (FILE *in, HEADER *h, FILE *out, int flags, const char *prefix)
     }
   }
 
-  if (flags & CH_UPDATE_LEN)
+  if (flags & CH_UPDATE_LEN &&
+      (flags & CH_NOLEN) == 0)
   {
     fprintf (out, "Content-Length: %ld\n", h->content->length);
     if (h->lines != 0 || h->content->length == 0)
@@ -359,6 +360,38 @@ mutt_copy_header (FILE *in, HEADER *h, FILE *out, int flags, const char *prefix)
   return (0);
 }
 
+/* Count the number of lines and bytes to be deleted in this body*/
+static int count_delete_lines (FILE *fp, BODY *b, long *length, size_t datelen)
+{
+  int dellines = 0;
+  long l;
+  int ch;
+
+  if (b->deleted)
+  {
+    fseek (fp, b->offset, SEEK_SET);
+    for (l = b->length ; l ; l --)
+    {
+      ch = getc (fp);
+      if (ch == EOF)
+	break;
+      if (ch == '\n')
+	dellines ++;
+    }
+    dellines -= 3;
+    *length -= b->length - (84 + datelen);
+    /* Count the number of digits exceeding the first one to write the size */
+    for (l = 10 ; b->length >= l ; l *= 10)
+      (*length) ++;
+  }
+  else
+  {
+    for (b = b->parts ; b ; b = b->next)
+      dellines += count_delete_lines (fp, b, length, datelen);
+  }
+  return dellines;
+}
+
 /* make a copy of a message
  
    fpout	where to write output
@@ -390,14 +423,64 @@ _mutt_copy_message (FILE *fpout, FILE *fpin, HEADER *hdr, BODY *body,
     if (flags & M_CM_PREFIX)
       chflags |= CH_PREFIX;
 
-   /* eventually update Content-Length/Lines: count in HEADER,
-    * for now we punt (don't copy them in mutt_copy_header() */
-     if (hdr->attach_del)
-     {
-       dprint (1, (debugfile, "changing flags\n"));
-       chflags |= CH_XMIT;
-       chflags &= ~CH_UPDATE_LEN;
-     }
+    else if (hdr->attach_del && (chflags & CH_UPDATE_LEN))
+    {
+      int new_lines;
+      long new_offset;
+      long new_length = body->length;
+      char date[SHORT_STRING];
+
+      mutt_make_date (date, sizeof (date));
+      date[5] = date[mutt_strlen (date) - 1] = '\"';
+
+      /* Count the number of lines and bytes to be deleted */
+      fseek (fpin, body->offset, SEEK_SET);
+      new_lines = hdr->lines -
+	count_delete_lines (fpin, body, &new_length, mutt_strlen (date));
+
+      /* Copy the headers */
+      if (mutt_copy_header (fpin, hdr, fpout,
+			    chflags | CH_NOLEN | CH_NONEWLINE, NULL))
+	return -1;
+      fprintf (fpout, "Content-Length: %ld\n", new_length);
+      if (new_lines <= 0)
+	new_lines = 0;
+      else
+	fprintf (fpout, "Lines: %d\n\n", new_lines);
+      if (ferror (fpout))
+	return -1;
+      new_offset = ftell (fpout);
+
+      /* Copy the body */
+      fseek (fpin, body->offset, SEEK_SET);
+      if (copy_delete_attach (body, fpin, fpout, date))
+	return -1;
+
+#ifdef DEBUG
+      {
+	long fail = ((ftell (fpout) - new_offset) - new_length);
+
+	if (fail)
+	{
+	  mutt_error ("The length calculation was wrong by %ld bytes", fail);
+	  new_length += fail;
+	  sleep (5);
+	}
+      }
+#endif
+
+      /* Update original message if we are sync'ing a mailfolder */ 
+      if (flags & M_CM_UPDATE)
+      {
+	hdr->attach_del = 0;
+	hdr->lines = new_lines;
+	body->offset = new_offset;
+	body->length = new_length;
+	mutt_free_body (&body->parts);
+      }
+
+      return 0;
+    }
 
     if (mutt_copy_header (fpin, hdr, fpout, chflags,
 			  (chflags & CH_PREFIX) ? prefix : NULL) == -1)
@@ -466,19 +549,7 @@ _mutt_copy_message (FILE *fpout, FILE *fpin, HEADER *hdr, BODY *body,
       } 
     }
     else
-    {
-      if (hdr->attach_del)
-      {
-	if (copy_delete_attach (hdr, hdr->content, fpin, fpout,
-				flags & M_CM_UPDATE) == -1)
-	  return -1;
-      }
-      else 
-      {
-	if (mutt_copy_bytes (fpin, fpout, body->length) == -1)
-	  return -1;
-      }
-    }
+      return mutt_copy_bytes (fpin, fpout, body->length);
   }
   return 0;
 }
@@ -539,138 +610,52 @@ mutt_append_message (CONTEXT *dest, CONTEXT *src, HEADER *hdr, int cmflags,
   return r;
 }
 
-static BODY *new_deleted_body ()
-{
-  BODY *b = safe_calloc (1, sizeof (BODY));
-  PARAMETER *p = mutt_new_parameter();
-  char date[SHORT_STRING];
-
-  mutt_make_date (date, sizeof (date));
-  date[strlen (date) - 1] = 0; /* cut off ending newline character */
-
-  p->attribute = safe_strdup ("access-type");
-  p->value = safe_strdup ("x-mutt-deleted");
-  p->next = mutt_new_parameter();
-  p->next->attribute = safe_strdup ("expiration");
-  p->next->value = safe_strdup (date + 6); /* cut off the leading "Date: " */
-
-  b->type = TYPEMESSAGE;
-  b->subtype = safe_strdup ("external-body");
-  b->parameter = p;
-  b->encoding = ENC7BIT;
-
-  return b;
-}
-
 /*
- * copy_delete_attach()
+ * This function copies a message body, while deleting _in_the_copy_
+ * any attachments which are marked for deletion.
+ * Nothing is changed in the original message -- this is left to the caller.
  *
- * This function copies a message into an mbox folder and deletes 
- * any attachments which are marked for deletion
- *
- * A side effect of this is that any message copied using this function
- * will not have content-length: and lines: headers, but these will be updated 
- * on the next sync of this mailbox
- *
- * The arguments are:
- * HEADER *h:   For the first call: The header of the message to copy,
- *              for recursive calls: NULL
- * BODY *b:     The message to copy
- * FILE *fpin:  Where to copy from
- * FILE *fpout: Where to copy to
- * int update:  Non-zero to update the original message's structure in memory
- *
- * The function will return:
- *              -1 on failure, +1 if any attachments were deleted, and else 0
+ * The function will return 0 on success and -1 on failure.
  */
-static int copy_delete_attach (HEADER *h, BODY *b, FILE *fpin, FILE *fpout,
-			       int update)
+static int copy_delete_attach (BODY *b, FILE *fpin, FILE *fpout, char *date)
 {
-  long saved_fpout_offset = ftell (fpout);
   BODY *part;
-  BODY *previous = NULL;
-  int did_deletion = 0;
-
-  dprint (1, (debugfile, "orig length: %ld  orig offset: %ld\n",
-	      b->length, b->offset));
 
   for (part = b->parts ; part ; part = part->next)
   {
-    if (part->deleted)
+    if (part->deleted || part->parts)
     {
-      BODY *deleted = new_deleted_body ();
-
-      /* Copy message from current position to deleted attachment headers */
-      mutt_copy_bytes (fpin, fpout, part->hdr_offset - ftell (fpin));
-
-      if (mutt_write_mime_header (deleted, fpout) == -1)
-	return -1;
-      if (putc ('\n', fpout) == EOF)
+      /* Copy till start of this part */
+      if (mutt_copy_bytes (fpin, fpout, part->hdr_offset - ftell (fpin)))
 	return -1;
 
-      if (mutt_copy_hdr (fpin, fpout, ftell (fpin), part->offset,
-			 0, NULL) == -1)
-	return -1;
-
-      /* Skip the deleted body */
-      fseek (fpin, part->offset + part->length, SEEK_SET);
-      did_deletion = 1;
-
-      if (update)
+      if (part->deleted)
       {
-	part->deleted = 0;
-	if (previous)
-	  previous->next = deleted;
-	else
-	  b->parts = deleted;
-	deleted->next = part->next;
-	deleted->parts = part;
-	part->next = NULL;
+	fprintf (fpout,
+		 "Content-Type: message/external-body; access-type=x-mutt-deleted;\n"
+		 "\texpiration=%s; length=%ld\n"
+		 "\n", date + 5, part->length);
+	if (ferror (fpout))
+	  return -1;
+
+	/* Copy the original mime headers */
+	if (mutt_copy_bytes (fpin, fpout, part->offset - ftell (fpin)))
+	  return -1;
+
+	/* Skip the deleted body */
+	fseek (fpin, part->offset + part->length, SEEK_SET);
       }
       else
-	mutt_free_body (&deleted);
-    }
-    else if (part->parts)
-    {
-      int rc;
-
-      /* Copy message from current position to attachment headers */
-      mutt_copy_bytes (fpin, fpout, part->hdr_offset - ftell (fpin));
-
-      rc = copy_delete_attach (NULL, part, fpin, fpout, update);
-
-      if (rc == -1)
-	return -1;
-      else if (rc == 1)
       {
-	did_deletion = 1;
-	if (part->hdr && update)
-	  part->hdr->lines = 0;
+	if (copy_delete_attach (part, fpin, fpout, date))
+	  return -1;
       }
     }
-    previous = part;
   }
 
-  /* Copy til end of message */
-  mutt_copy_bytes (fpin, fpout, b->length - (ftell (fpin) - b->offset));
+  /* Copy the last parts */
+  if (mutt_copy_bytes (fpin, fpout, b->offset + b->length - ftell (fpin)))
+    return -1;
 
-  /*
-   * Update the content-length and offset.  This offset will be wrong for
-   * mbox/mh type folders, but will be corrected in mbox_sync_mailbox()
-   */
-  if (update && did_deletion)
-  {
-    if (h)
-    {
-      h->attach_del = 0;
-      h->lines = 0;
-    }
-    b->offset = saved_fpout_offset;
-    b->length = ftell (fpout) - saved_fpout_offset;
-
-    dprint (1, (debugfile, "new length: %ld  new offset: %ld\n",
-		b->length, b->offset));
-  }
-
-  return did_deletion;
+  return 0;
 }
