@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_main.c,v 1.23 1998/10/28 16:39:56 roessler Exp $";
+static const char rcsid[]="$Id: curs_main.c,v 1.25 1998/11/09 11:15:29 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -138,7 +138,13 @@ void index_make_entry (char *s, size_t l, MUTTMENU *menu, int num)
 
 int index_color (int index_no)
 {
-  return Context->hdrs[Context->v2r[index_no]]->pair;
+  HEADER *h = Context->hdrs[Context->v2r[index_no]];
+
+  if (h->pair)
+    return h->pair;
+
+  mutt_set_header_color (Context, h);
+  return h->pair;
 }
 
 static int ci_next_undeleted (int msgno)
@@ -965,7 +971,11 @@ int mutt_index_menu (void)
 	if ((menu->menu == MENU_MAIN)
 	    && (query_quadoption (OPT_QUIT, 
 				  _("Exit Mutt without saving?")) == M_YES))
+	{
+	  mx_fastclose_mailbox (Context);
+	  safe_free ((void **) &Context);
 	  done = 1;
+	}
 	break;
 
       case OP_MAIN_NEXT_UNDELETED:
@@ -1726,12 +1736,3 @@ void mutt_set_header_color (CONTEXT *ctx, HEADER *curhdr)
    }
   curhdr->pair = ColorDefs[MT_COLOR_NORMAL];
 }
-
-void mutt_cache_index_colors (CONTEXT *ctx)
-{
- int i;
-
- if (ctx)
-   for (i = 0; i < ctx->msgcount; i++)
-     mutt_set_header_color (ctx, ctx->hdrs[i]);
-}
