@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: handler.c,v 1.22 1998/11/09 10:58:45 roessler Exp $";
+static const char rcsid[]="$Id: handler.c,v 1.25 1998/11/14 08:22:02 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -319,16 +319,16 @@ void mutt_decode_uuencoded (STATE *s, BODY *b, int istext)
   {
     if ((fgets(tmps, sizeof(tmps), s->fpin)) == NULL)
       return;
-    len -= strlen(tmps);
-    if ((!strncmp (tmps, "begin", 5)) && ISSPACE (tmps[5]))
+    len -= mutt_strlen(tmps);
+    if ((!mutt_strncmp (tmps, "begin", 5)) && ISSPACE (tmps[5]))
       break;
   }
   while(len > 0)
   {
     if ((fgets(tmps, sizeof(tmps), s->fpin)) == NULL)
       return;
-    len -= strlen(tmps);
-    if (!strncmp (tmps, "end", 3))
+    len -= mutt_strlen(tmps);
+    if (!mutt_strncmp (tmps, "end", 3))
       break;
     pt = tmps;
     linelen = decode_byte (*pt);
@@ -479,7 +479,7 @@ static void enriched_wrap (struct enriched_state *stte)
   if (stte->s->prefix)
   {
     state_puts (stte->s->prefix, stte->s);
-    stte->indent_len += strlen (stte->s->prefix);
+    stte->indent_len += mutt_strlen (stte->s->prefix);
   }
 
   if (stte->tag_level[RICH_EXCERPT])
@@ -490,12 +490,12 @@ static void enriched_wrap (struct enriched_state *stte)
       if (stte->s->prefix)
       {
 	state_puts (stte->s->prefix, stte->s);
-	    stte->indent_len += strlen (stte->s->prefix);
+	    stte->indent_len += mutt_strlen (stte->s->prefix);
       }
       else
       {
 	state_puts ("> ", stte->s);
-	stte->indent_len += strlen ("> ");
+	stte->indent_len += mutt_strlen ("> ");
       }
       x--;
     }
@@ -608,7 +608,7 @@ static void enriched_puts (char *s, struct enriched_state *stte)
 {
   char *c;
 
-  if (stte->buff_len < stte->buff_used + strlen(s))
+  if (stte->buff_len < stte->buff_used + mutt_strlen(s))
   {
     stte->buff_len += LONG_STRING;
     safe_realloc ((void **) &stte->buffer, stte->buff_len + 1);
@@ -630,7 +630,7 @@ static void enriched_set_flags (const char *tag, struct enriched_state *stte)
     tagptr++;
   
   for (i = 0, j = -1; EnrichedTags[i].tag_name; i++)
-    if (strcasecmp (EnrichedTags[i].tag_name,tagptr) == 0)
+    if (mutt_strcasecmp (EnrichedTags[i].tag_name,tagptr) == 0)
     {
       j = EnrichedTags[i].index;
       break;
@@ -648,35 +648,35 @@ static void enriched_set_flags (const char *tag, struct enriched_state *stte)
       if ((stte->s->flags & M_DISPLAY) && j == RICH_PARAM && stte->tag_level[RICH_COLOR])
       {
 	stte->param[stte->param_len] = '\0';
-	if (!strcasecmp(stte->param, "black"))
+	if (!mutt_strcasecmp(stte->param, "black"))
 	{
 	  enriched_puts("\033[30m", stte);
 	}
-	else if (!strcasecmp(stte->param, "red"))
+	else if (!mutt_strcasecmp(stte->param, "red"))
 	{
 	  enriched_puts("\033[31m", stte);
 	}
-	else if (!strcasecmp(stte->param, "green"))
+	else if (!mutt_strcasecmp(stte->param, "green"))
 	{
 	  enriched_puts("\033[32m", stte);
 	}
-	else if (!strcasecmp(stte->param, "yellow"))
+	else if (!mutt_strcasecmp(stte->param, "yellow"))
 	{
 	  enriched_puts("\033[33m", stte);
 	}
-	else if (!strcasecmp(stte->param, "blue"))
+	else if (!mutt_strcasecmp(stte->param, "blue"))
 	{
 	  enriched_puts("\033[34m", stte);
 	}
-	else if (!strcasecmp(stte->param, "magenta"))
+	else if (!mutt_strcasecmp(stte->param, "magenta"))
 	{
 	  enriched_puts("\033[35m", stte);
 	}
-	else if (!strcasecmp(stte->param, "cyan"))
+	else if (!mutt_strcasecmp(stte->param, "cyan"))
 	{
 	  enriched_puts("\033[36m", stte);
 	}
-	else if (!strcasecmp(stte->param, "white"))
+	else if (!mutt_strcasecmp(stte->param, "white"))
 	{
 	  enriched_puts("\033[37m", stte);
 	}
@@ -718,7 +718,7 @@ void text_enriched_handler (BODY *a, STATE *s)
   if (s->prefix)
   {
     state_puts (s->prefix, s);
-    stte.indent_len += strlen (s->prefix);
+    stte.indent_len += mutt_strlen (s->prefix);
   }
 
   while (state != DONE)
@@ -846,7 +846,7 @@ static void alternative_handler (BODY *a, STATE *s)
     else
     {
       wild = 1;
-      btlen = strlen (t->data);
+      btlen = mutt_strlen (t->data);
     }
 
     if (a && a->parts) 
@@ -856,10 +856,10 @@ static void alternative_handler (BODY *a, STATE *s)
     while (b)
     {
       const char *bt = TYPE(b);
-      if (!strncasecmp (bt, t->data, btlen) && bt[btlen] == 0)
+      if (!mutt_strncasecmp (bt, t->data, btlen) && bt[btlen] == 0)
       {
 	/* the basetype matches */
-	if (wild || !strcasecmp (t->data + btlen + 1, b->subtype))
+	if (wild || !mutt_strcasecmp (t->data + btlen + 1, b->subtype))
 	{
 	  choice = b;
 	}
@@ -904,17 +904,17 @@ static void alternative_handler (BODY *a, STATE *s)
     {
       if (b->type == TYPETEXT)
       {
-	if (! strcasecmp ("plain", b->subtype) && type <= TXTPLAIN)
+	if (! mutt_strcasecmp ("plain", b->subtype) && type <= TXTPLAIN)
 	{
 	  choice = b;
 	  type = TXTPLAIN;
 	}
-	else if (! strcasecmp ("enriched", b->subtype) && type <= TXTENRICHED)
+	else if (! mutt_strcasecmp ("enriched", b->subtype) && type <= TXTENRICHED)
 	{
 	  choice = b;
 	  type = TXTENRICHED;
 	}
-	else if (! strcasecmp ("html", b->subtype) && type <= TXTHTML)
+	else if (! mutt_strcasecmp ("html", b->subtype) && type <= TXTHTML)
 	{
 	  choice = b;
 	  type = TXTHTML;
@@ -1010,8 +1010,8 @@ int mutt_can_decode (BODY *a)
 
 
 #ifdef _PGPPATH
-    if (strcasecmp (a->subtype, "signed") == 0 ||
-	strcasecmp (a->subtype, "encrypted") == 0)
+    if (mutt_strcasecmp (a->subtype, "signed") == 0 ||
+	mutt_strcasecmp (a->subtype, "encrypted") == 0)
       return (1);
     else
 #endif
@@ -1047,7 +1047,6 @@ int mutt_can_decode (BODY *a)
 void multipart_handler (BODY *a, STATE *s)
 {
   BODY *b, *p;
-  char buffer[STRING];
   char length[5];
   struct stat st;
   int count;
@@ -1060,7 +1059,7 @@ void multipart_handler (BODY *a, STATE *s)
     b->length = (long) st.st_size;
     b->parts = mutt_parse_multipart (s->fpin,
 		  mutt_get_parameter ("boundary", a->parameter),
-		  (long) st.st_size, strcasecmp ("digest", a->subtype) == 0);
+		  (long) st.st_size, mutt_strcasecmp ("digest", a->subtype) == 0);
   }
   else
     b = a;
@@ -1069,8 +1068,7 @@ void multipart_handler (BODY *a, STATE *s)
   {
     if (s->flags & M_DISPLAY)
     {
-      snprintf (buffer, sizeof (buffer), _("[-- Attachment #%d"), count);
-      state_puts (buffer, s);
+      state_printf (s, _("[-- Attachment #%d"), count);
       if (p->description || p->filename || p->form_name)
       {
 	state_puts (": ", s);
@@ -1080,11 +1078,9 @@ void multipart_handler (BODY *a, STATE *s)
       state_puts (" --]\n", s);
 
       mutt_pretty_size (length, sizeof (length), p->length);
-
-      snprintf (buffer, sizeof (buffer),
-		_("[-- Type: %s/%s, Encoding: %s, Size: %s --]\n"),
-	       TYPE (p), p->subtype, ENCODING (p->encoding), length);
-      state_puts (buffer, s);
+      
+      state_printf (s, _("[-- Type: %s/%s, Encoding: %s, Size: %s --]\n"),
+		    TYPE (p), p->subtype, ENCODING (p->encoding), length);
       if (!option (OPTWEED))
       {
 	fseek (s->fpin, p->hdr_offset, 0);
@@ -1096,16 +1092,11 @@ void multipart_handler (BODY *a, STATE *s)
     else
     {
       if (p->description && mutt_can_decode (p))
-      {
-	state_puts ("Content-Description: ", s);
-	state_puts (p->description, s);
-	state_putc ('\n', s);
-      }
+	state_printf (s, "Content-Description: %s\n", p->description);
+
       if (p->form_name)
-      {
-	state_puts (p->form_name, s);
-	state_puts (": \n", s);
-      }
+	state_printf(s, "%s: \n", p->form_name);
+
     }
     mutt_body_handler (p, s);
     state_putc ('\n', s);
@@ -1147,10 +1138,7 @@ void autoview_handler (BODY *a, STATE *s)
 
     if (s->flags & M_DISPLAY)
     {
-      char mesg[STRING];
-
-      snprintf (mesg, sizeof (buffer), _("[-- Autoview using %s --]\n"), command);
-      state_puts (mesg, s);
+      state_printf (s, _("[-- Autoview using %s --]\n"), command);
       mutt_message(_("Invoking autoview command: %s"),command);
     }
 
@@ -1188,13 +1176,8 @@ void autoview_handler (BODY *a, STATE *s)
       if (fgets (buffer, sizeof(buffer), fperr)) 
       {
 	if (s->flags & M_DISPLAY) 
-	{
-	  char mesg[STRING];
+	  state_printf (s, _("[-- Autoview stderr of %s --]\n"), command);
 
-	  snprintf (mesg, sizeof (buffer), _("[-- Autoview stderr of %s --]\n"), 
-	      command);
-	  state_puts (mesg, s);
-	}
 	state_puts (s->prefix, s);
 	state_puts (buffer, s);
 	while (fgets (buffer, sizeof(buffer), fperr) != NULL)
@@ -1211,13 +1194,9 @@ void autoview_handler (BODY *a, STATE *s)
       if (fgets (buffer, sizeof(buffer), fperr))
       {
 	if (s->flags & M_DISPLAY)
-	{
-	  char mesg[STRING];
-
-	  snprintf (mesg, sizeof (buffer), _("[-- Autoview stderr of %s --]\n"), 
-	      command);
-	  state_puts (mesg, s);
-	}
+	  state_printf (s, _("[-- Autoview stderr of %s --]\n"), 
+			command);
+	
 	state_puts (buffer, s);
 	mutt_copy_stream (fperr, s->fpout);
       }
@@ -1263,25 +1242,50 @@ static void external_body_handler (BODY *b, STATE *s)
   else
     expire = -1;
 
-  if (!strcasecmp (access_type, "x-mutt-deleted"))
+  if (!mutt_strcasecmp (access_type, "x-mutt-deleted"))
   {
     if (s->flags & M_DISPLAY)
     {
-      fprintf (s->fpout, _("[-- This %s/%s attachment is deleted --]\n"),
+      char *length;
+      char pretty_size[10];
+
+      state_printf (s, _("[-- This %s/%s attachment "),
 	       TYPE(b->parts), b->parts->subtype);
+      length = mutt_get_parameter ("length", b->parameter);
+      if (length)
+      {
+	mutt_pretty_size (pretty_size, sizeof (pretty_size),
+			  strtol (length, NULL, 10));
+	state_printf (s, _("(size %s bytes) "), pretty_size);
+      }
+      state_puts (_("has been deleted --]\n"), s);
+
       if (expire != -1)
-	fprintf (s->fpout, _("[-- on %s --]\n"), expiration);
+	state_printf (s, _("[-- on %s --]\n"), expiration);
       mutt_copy_hdr (s->fpin, s->fpout, ftell (s->fpin), b->parts->offset,
 		     (option (OPTWEED) ? (CH_WEED | CH_REORDER) : 0) |
 		     CH_DECODE , NULL);
     }
   }
+  else if(expire < time(NULL))
+  {
+    if (s->flags & M_DISPLAY)
+    {
+      state_printf (s, _("[-- This %s/%s attachment is not included, --]\n"
+			 "[-- and the indicated external source has --]\n"
+			 "[-- expired. --]\n"),
+		    TYPE(b->parts), b->parts->subtype);
+      mutt_copy_hdr(s->fpin, s->fpout, ftell (s->fpin), b->parts->offset,
+		    (option (OPTWEED) ? (CH_WEED | CH_REORDER) : 0) |
+		    CH_DECODE, NULL);
+    }
+  }
   else
   {
     if (s->flags & M_DISPLAY)
     {
-      fprintf (s->fpout,
-	       _("[-- This %s/%s attachment is not included --]\n"
+      state_printf (s,
+	       _("[-- This %s/%s attachment is not included, --]\n"
 		 "[-- and the indicated access-type %s is unsupported --]\n"),
 	       TYPE(b->parts), b->parts->subtype, access_type);
       mutt_copy_hdr (s->fpin, s->fpout, ftell (s->fpin), b->parts->offset,
@@ -1335,25 +1339,25 @@ void mutt_body_handler (BODY *b, STATE *s)
   }
   else if (b->type == TYPETEXT)
   {
-    if (strcasecmp ("plain", b->subtype) == 0)
+    if (mutt_strcasecmp ("plain", b->subtype) == 0)
     {
       /* avoid copying this part twice since removing the transfer-encoding is
        * the only operation needed.
        */
       plaintext = 1;
     }
-    else if (strcasecmp ("enriched", b->subtype) == 0)
+    else if (mutt_strcasecmp ("enriched", b->subtype) == 0)
       handler = text_enriched_handler;
-    else if (strcasecmp ("rfc822-headers", b->subtype) == 0)
+    else if (mutt_strcasecmp ("rfc822-headers", b->subtype) == 0)
       plaintext = 1;
   }
   else if (b->type == TYPEMESSAGE)
   {
     if(mutt_is_message_type(b->type, b->subtype))
       handler = message_handler;
-    else if (!strcasecmp ("delivery-status", b->subtype))
+    else if (!mutt_strcasecmp ("delivery-status", b->subtype))
       plaintext = 1;
-    else if (!strcasecmp ("external-body", b->subtype))
+    else if (!mutt_strcasecmp ("external-body", b->subtype))
       handler = external_body_handler;
   }
   else if (b->type == TYPEMULTIPART)
@@ -1367,31 +1371,31 @@ void mutt_body_handler (BODY *b, STATE *s)
 
 
 
-    if (strcasecmp ("alternative", b->subtype) == 0)
+    if (mutt_strcasecmp ("alternative", b->subtype) == 0)
       handler = alternative_handler;
 
 
 
 #ifdef _PGPPATH
-    else if (strcasecmp ("signed", b->subtype) == 0)
+    else if (mutt_strcasecmp ("signed", b->subtype) == 0)
     {
       p = mutt_get_parameter ("protocol", b->parameter);
 
       if (!p)
         mutt_error _("Error: multipart/signed has no protocol.");
-      else if (strcasecmp ("application/pgp-signature", p) == 0)
+      else if (mutt_strcasecmp ("application/pgp-signature", p) == 0)
       {
 	if (s->flags & M_VERIFY)
 	  handler = pgp_signed_handler;
       }
     }
-    else if (strcasecmp ("encrypted", b->subtype) == 0)
+    else if (mutt_strcasecmp ("encrypted", b->subtype) == 0)
     {
       p = mutt_get_parameter ("protocol", b->parameter);
 
       if (!p)
         mutt_error _("Error: multipart/encrypted has no protocol parameter!");
-      else if (strcasecmp ("application/pgp-encrypted", p) == 0)
+      else if (mutt_strcasecmp ("application/pgp-encrypted", p) == 0)
         handler = pgp_encrypted_handler;
     }
 #endif /* _PGPPATH */
@@ -1491,7 +1495,7 @@ void mutt_body_handler (BODY *b, STATE *s)
   }
   else if (s->flags & M_DISPLAY)
   {
-    fprintf (s->fpout, _("[-- %s/%s is unsupported "), TYPE (b), b->subtype);
+    state_printf (s, _("[-- %s/%s is unsupported "), TYPE (b), b->subtype);
     if (!option (OPTVIEWATTACH))
     {
       if (km_expand_key (type, sizeof(type),
