@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: headers.c,v 1.9 1998/10/15 20:33:32 roessler Exp $";
+static const char rcsid[]="$Id: headers.c,v 1.10 1998/11/10 22:14:23 roessler Exp $";
 /* 
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -159,9 +159,9 @@ void mutt_edit_headers (const char *editor,
      * not, remove the references: field later so that we can generate a new
      * message based upon this one.
      */
-    if (strncasecmp ("in-reply-to:", cur->data, 12) == 0)
+    if (mutt_strncasecmp ("in-reply-to:", cur->data, 12) == 0)
       in_reply_to = 1;
-    else if (fcc && strncasecmp ("fcc:", cur->data, 4) == 0)
+    else if (fcc && mutt_strncasecmp ("fcc:", cur->data, 4) == 0)
     {
       p = cur->data + 4;
       SKIPWS (p);
@@ -172,7 +172,7 @@ void mutt_edit_headers (const char *editor,
       }
       keep = 0;
     }
-    else if (strncasecmp ("attach:", cur->data, 7) == 0)
+    else if (mutt_strncasecmp ("attach:", cur->data, 7) == 0)
     {
       BODY *body;
       BODY *parts;
@@ -208,7 +208,7 @@ void mutt_edit_headers (const char *editor,
 
 
 #ifdef _PGPPATH
-    else if (strncasecmp ("pgp:", cur->data, 4) == 0)
+    else if (mutt_strncasecmp ("pgp:", cur->data, 4) == 0)
     {
       msg->pgp = mutt_parse_pgp_hdr (cur->data + 4, 0);
       keep = 0;
