@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: hook.c,v 1.6 1998/10/15 20:33:35 roessler Exp $";
+static const char rcsid[]="$Id: hook.c,v 1.7 1998/11/10 22:14:26 roessler Exp $";
 /* 
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  *
@@ -114,14 +114,14 @@ int mutt_parse_hook (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
   {
     if (ptr->type == data &&
 	ptr->rx.not == not &&
-	!strcmp (pattern.data, ptr->rx.pattern))
+	!mutt_strcmp (pattern.data, ptr->rx.pattern))
     {
       if (data & (M_FOLDERHOOK | M_SENDHOOK))
       {
 	/* folder-hook and send-hook allow multiple commands with the same
 	   pattern, so if we've already seen this pattern/command pair, just
 	   ignore it instead of creating a duplicate */
-	if (!strcmp (ptr->command, command.data))
+	if (!mutt_strcmp (ptr->command, command.data))
 	{
 	  FREE (&command.data);
 	  FREE (&pattern.data);
