@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: main.c,v 1.17 1998/11/09 11:07:25 roessler Exp $";
+static const char rcsid[]="$Id: main.c,v 1.19 1998/11/10 22:14:32 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -51,6 +51,9 @@ Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>\n\
 Copyright (C) 1997-8 Thomas Roessler <roessler@guug.de>\n\
 Copyright (C) 1998   Werner Koch <wk@isil.d.shuttle.de>\n\
 Copyright (C) 1998   Ruslan Ermilov <ru@ucb.crimea.ua>\n\
+\n\
+Lots of others not mentioned here contributed lots of code,\n\
+fixes, and suggestions.\n\
 \n\
     This program is free software; you can redistribute it and/or modify\n\
     it under the terms of the GNU General Public License as published by\n\
@@ -548,7 +551,7 @@ int main (int argc, char **argv)
 
     if (infile)
     {
-      if (strcmp ("-", infile) == 0)
+      if (mutt_strcmp ("-", infile) == 0)
 	fin = stdin;
       else
       {
