@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: menu.c,v 1.8 1998/10/15 20:33:43 roessler Exp $";
+static const char rcsid[]="$Id: menu.c,v 1.9 1998/11/10 22:14:34 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  *
@@ -79,7 +79,7 @@ static void print_enriched_string (int attr, unsigned char *s, int do_color)
 void menu_pad_string (char *s, size_t l)
 {
 #if !defined(HAVE_BKGDSET) && !defined (USE_SLANG_CURSES)
-  int n = strlen (s);
+  int n = mutt_strlen (s);
 #endif
   int shift = option (OPTARROWCURSOR) ? 3 : 0;
   
