@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mh.c,v 1.14 1998/10/15 20:33:44 roessler Exp $";
+static const char rcsid[]="$Id: mh.c,v 1.16 1998/11/18 20:40:52 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -77,7 +77,7 @@ static void maildir_parse_flags(HEADER *h, const char *path)
   h->read = 0;
   h->replied = 0;
   
-  if ((p = strrchr (path, ':')) != NULL && strncmp (p + 1, "2,", 2) == 0)
+  if ((p = strrchr (path, ':')) != NULL && mutt_strncmp (p + 1, "2,", 2) == 0)
   {
     p += 3;
     while (*p)
@@ -227,7 +227,7 @@ static int maildir_parse_dir(CONTEXT *ctx, struct maildir ***last,
   if(subdir)
   {
     snprintf(buf, sizeof(buf), "%s/%s", ctx->path, subdir);
-    is_old = (strcmp("cur", subdir) == 0) && option(OPTMARKOLD);
+    is_old = (mutt_strcmp("cur", subdir) == 0) && option(OPTMARKOLD);
   }
   else
     strfcpy(buf, ctx->path, sizeof(buf));
@@ -451,7 +451,7 @@ static int maildir_sync_message (CONTEXT *ctx, int msgno)
   snprintf (fullpath, sizeof (fullpath), "%s/%s", ctx->path, partpath);
   snprintf (oldpath, sizeof (oldpath), "%s/%s", ctx->path, h->path);
 
-  if (strcmp (fullpath, oldpath) == 0 && !h->attach_del)
+  if (mutt_strcmp (fullpath, oldpath) == 0 && !h->attach_del)
   {
     /* message hasn't really changed */
     return 0;
@@ -620,7 +620,8 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
   if(ctx->magic == M_MAILDIR)
     ctx->mtime_cur = st_cur.st_mtime;
   ctx->mtime = st.st_mtime;
-  
+
+#if 0
   if(Sort != SORT_ORDER)
   {
     short old_sort;
@@ -630,7 +631,8 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
     mutt_sort_headers(ctx, 1);
     Sort = old_sort;
   }
-    
+#endif
+
   md = NULL;
   last = &md;
   
