@@ -1,4 +1,4 @@
-/* $Id: mutt.h,v 1.28 1998/10/28 18:36:12 roessler Exp $ */
+/* $Id: mutt.h,v 1.32 1998/11/18 06:55:56 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -20,6 +20,9 @@
 #include "config.h"
 
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h> /* needed for SEEK_SET */
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
@@ -82,6 +85,7 @@
 #define CH_MIME		(1<<9) /* ignore MIME fields */
 #define CH_UPDATE_LEN	(1<<10) /* update Lines: and Content-Length: */
 #define CH_TXTPLAIN	(1<<11) /* generate text/plain MIME headers */
+#define CH_NOLEN	(1<<12) /* don't write Content-Length: and Lines: */
 
 /* flags for mutt_enter_string() */
 #define  M_ALIAS   1      /* do alias "completion" by calling up the alias-menu */
@@ -639,6 +643,7 @@ typedef struct
 typedef struct attachptr
 {
   BODY *content;
+  int parent_type;
   char *tree;
   int level;
   int num;
@@ -671,6 +676,7 @@ typedef struct
 #define state_putc(x,y) fputc(x,(y)->fpout)
 
 void state_prefix_putc(char, STATE *);
+int  state_printf(STATE *, const char *, ...);
 
 #include "protos.h"
 #include "globals.h"
