@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pager.c,v 1.20 1998/11/09 10:47:18 roessler Exp $";
+static const char rcsid[]="$Id: pager.c,v 1.22 1998/11/17 09:22:18 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -55,7 +55,7 @@ static const char rcsid[]="$Id: pager.c,v 1.20 1998/11/09 10:47:18 roessler Exp
 #define CHECK_MODE(x)	if (!(x)) \
 			{ \
 			  	mutt_flushinp (); \
-				mutt_error ("Not available in this menu."); \
+				mutt_error _("Not available in this menu."); \
 				break; \
 			}
 
@@ -69,7 +69,7 @@ static const char rcsid[]="$Id: pager.c,v 1.20 1998/11/09 10:47:18 roessler Exp
 #define CHECK_ATTACH if(option(OPTATTACHMSG)) \
 		     {\
 			mutt_flushinp (); \
-			mutt_error ("Function not permitted in attach-message mode."); \
+			mutt_error _("Function not permitted in attach-message mode."); \
 			break; \
 		     }
 
@@ -407,7 +407,7 @@ classify_quote (struct q_class_t **QuoteList, const char *qptr,
     {
       /* case 1: check the top level nodes */
 
-      if (strncmp (qptr, q_list->prefix, length) == 0)
+      if (mutt_strncmp (qptr, q_list->prefix, length) == 0)
       {
 	if (length == q_list->length)
 	  return q_list;	/* same prefix: return the current class */
@@ -501,7 +501,7 @@ classify_quote (struct q_class_t **QuoteList, const char *qptr,
       /* case 2: try subclassing the current top level node */
       
       /* tmp != NULL means we already found a shorter prefix at case 1 */
-      if (tmp == NULL && strncmp (qptr, q_list->prefix, q_list->length) == 0)
+      if (tmp == NULL && mutt_strncmp (qptr, q_list->prefix, q_list->length) == 0)
       {
 	/* ok, it's a subclass somewhere on this branch */
 
@@ -516,7 +516,7 @@ classify_quote (struct q_class_t **QuoteList, const char *qptr,
 	{
 	  if (length <= q_list->length)
 	  {
-	    if (strncmp (tail_qptr, (q_list->prefix) + offset, tail_lng) == 0)
+	    if (mutt_strncmp (tail_qptr, (q_list->prefix) + offset, tail_lng) == 0)
 	    {
 	      /* same prefix: return the current class */
 	      if (length == q_list->length)
@@ -604,7 +604,7 @@ classify_quote (struct q_class_t **QuoteList, const char *qptr,
 	  else
 	  {
 	    /* longer than the current prefix: try subclassing it */
-	    if (tmp == NULL && strncmp (tail_qptr, (q_list->prefix) + offset,
+	    if (tmp == NULL && mutt_strncmp (tail_qptr, (q_list->prefix) + offset,
 			  q_list->length - offset) == 0)
 	    {
 	      /* still a subclass: go down one level */
@@ -720,9 +720,9 @@ resolve_types (char *buf, struct line_t *lineInfo, int n, int last,
       }
     }
   }
-  else if (strncmp ("[-- ", buf, 4) == 0)
+  else if (mutt_strncmp ("[-- ", buf, 4) == 0)
     lineInfo[n].type = MT_COLOR_ATTACHMENT;
-  else if (strcmp ("-- \n", buf) == 0 || strcmp ("-- \r\n", buf) == 0)
+  else if (mutt_strcmp ("-- \n", buf) == 0 || mutt_strcmp ("-- \r\n", buf) == 0)
   {
     i = n + 1;
 
@@ -1020,6 +1020,10 @@ display_line (FILE *f, long *last_pos, struct line_t **lineInfo, int n,
 
       resolve_types ((char *) fmt, *lineInfo, n, *last,
 		      QuoteList, q_level, force_redraw, flags & M_SHOWCOLOR);
+
+      /* avoid race condition for continuation lines when scrolling up */
+      for (m = n + 1; m < *last && (*lineInfo)[m].offset && (*lineInfo)[m].continuation; m++)
+	(*lineInfo)[m].type = (*lineInfo)[n].type;
     }
 
     /* this also prevents searching through the hidden lines */
@@ -1028,7 +1032,7 @@ display_line (FILE *f, long *last_pos, struct line_t **lineInfo, int n,
   }
 
   /* At this point, (*lineInfo[n]).quote may still be undefined. We 
-   * don't wont to compute it every time M_TYPES is set, since this
+   * don't want to compute it every time M_TYPES is set, since this
    * would slow down the "bottom" function unacceptably. A compromise
    * solution is hence to call regexec() again, just to find out the
    * length of the quote prefix.
