@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: postpone.c,v 1.18 1998/10/27 09:41:15 roessler Exp $";
+static const char rcsid[]="$Id: postpone.c,v 1.20 1998/11/17 09:22:22 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -230,7 +230,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
 
   for (tmp = hdr->env->userhdrs; tmp; )
   {
-    if (strncasecmp ("X-Mutt-References:", tmp->data, 18) == 0)
+    if (mutt_strncasecmp ("X-Mutt-References:", tmp->data, 18) == 0)
     {
       if (ctx)
       {
@@ -253,7 +253,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
       if (*cur)
 	code |= SENDREPLY;
     }
-    else if (strncasecmp ("X-Mutt-Fcc:", tmp->data, 11) == 0)
+    else if (mutt_strncasecmp ("X-Mutt-Fcc:", tmp->data, 11) == 0)
     {
       p = tmp->data + 11;
       SKIPWS (p);
@@ -274,7 +274,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
 
 
 #ifdef _PGPPATH
-    else if (strncmp ("Pgp:", tmp->data, 4) == 0)
+    else if (mutt_strncmp ("Pgp:", tmp->data, 4) == 0)
     {
       hdr->pgp = mutt_parse_pgp_hdr (tmp->data+4, 1);
        
@@ -405,17 +405,7 @@ int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
   {
     BODY *b;
 
-    fseek (msg->fp, hdr->content->offset, 0);
-
-    if (hdr->content->type == TYPEMULTIPART)
-    {
-      hdr->content->parts = mutt_parse_multipart (msg->fp, 
-	       mutt_get_parameter ("boundary", hdr->content->parameter),
-	       hdr->content->offset + hdr->content->length,
-	       strcasecmp ("digest", hdr->content->subtype) == 0);
-    }
-    else
-      hdr->content->parts = mutt_parse_messageRFC822 (msg->fp, hdr->content);
+    mutt_parse_part (msg->fp, hdr->content);
 
     /* Now that we know what was in the other message, convert to the new
      * message.
