@@ -1,4 +1,4 @@
-/* $Id: protos.h,v 1.29 1998/11/09 11:52:26 roessler Exp $ */
+/* $Id: protos.h,v 1.34 1998/11/18 22:57:02 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -63,8 +63,10 @@ int _mutt_traverse_thread (CONTEXT *ctx, HEADER *hdr, int flag);
 typedef const char * format_t (char *, size_t, char, const char *, const char *, const char *, const char *, unsigned long, format_flag);
 
 void mutt_FormatString (char *, size_t, const char *, format_t *, unsigned long, format_flag);
-
+void mutt_parse_content_type (char *, BODY *);
 void mutt_update_encoding (BODY *a);
+void mutt_generate_boundary (PARAMETER **);
+void mutt_set_parameter (const char *, const char *, PARAMETER **);
 
 FILE *mutt_open_read (const char *, pid_t *);
 
@@ -90,7 +92,7 @@ BODY *mutt_read_mime_header (FILE *, int);
 ENVELOPE *mutt_read_rfc822_header (FILE *, HEADER *, short);
 HEADER *mutt_dup_header (HEADER *);
 
-ATTACHPTR **mutt_gen_attach_list (BODY *, ATTACHPTR **, short *, short *, int, int);
+ATTACHPTR **mutt_gen_attach_list (BODY *, int, ATTACHPTR **, short *, short *, int, int);
 
 time_t mutt_local_tz (void);
 time_t mutt_mktime (struct tm *, int);
@@ -110,7 +112,6 @@ const char *mutt_attach_fmt (
 
 char *mutt_expand_path (char *, size_t);
 char *mutt_find_hook (int, const char *);
-char *mutt_generate_boundary (void);
 char *mutt_gen_msgid (void);
 char *mutt_get_name (ADDRESS *);
 char *mutt_get_parameter (const char *, PARAMETER *);
@@ -166,6 +167,7 @@ void mutt_mktemp (char *);
 void mutt_nocurses_error (const char *, ...);
 void mutt_normalize_time (struct tm *);
 void mutt_parse_mime_message (CONTEXT *ctx, HEADER *);
+void mutt_parse_part (FILE *, BODY *);
 void mutt_pipe_message_to_state (HEADER *, STATE *);
 void mutt_perror (const char *);
 void mutt_prepare_envelope (ENVELOPE *);
@@ -264,6 +266,10 @@ int mutt_save_message (HEADER *, int, int, int, int *);
 int mutt_search_command (int, int);
 int mutt_compose_menu (HEADER *, char *, size_t, HEADER *);
 int mutt_strcmp (const char *, const char *);
+int mutt_strcasecmp (const char *, const char *);
+int mutt_strncmp (const char *, const char *, size_t);
+int mutt_strncasecmp (const char *, const char *, size_t);
+size_t mutt_strlen (const char *);
 int mutt_thread_set_flag (HEADER *, int, int, int);
 int mutt_user_is_recipient (HEADER *);
 int mutt_view_attachment (FILE*, BODY *, int);
@@ -427,4 +433,3 @@ int ioctl (int, int, ...);
 /* unsorted */
 void ci_bounce_message (HEADER *, int *);
 void ci_send_message (int, HEADER *, char *, CONTEXT *, HEADER *);
-void ci_attach (BODY *);
