@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: recvattach.c,v 1.20 1998/10/15 20:33:58 roessler Exp $";
+static const char rcsid[]="$Id: recvattach.c,v 1.24 1998/11/18 22:05:22 roessler Exp $";
 /*
  * Copyright (C) 1996-1998 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -78,7 +78,7 @@ void mutt_update_tree (ATTACHPTR **idx, short idxlen)
 
     if (idx[x]->tree)
     {
-      if (strcmp (idx[x]->tree, buf) != 0)
+      if (mutt_strcmp (idx[x]->tree, buf) != 0)
       {
 	safe_free ((void **) &idx[x]->tree);
 	idx[x]->tree = safe_strdup (buf);
@@ -97,6 +97,7 @@ void mutt_update_tree (ATTACHPTR **idx, short idxlen)
 }
 
 ATTACHPTR **mutt_gen_attach_list (BODY *m,
+				  int parent_type,
 				  ATTACHPTR **idx,
 				  short *idxlen,
 				  short *idxmax,
@@ -116,18 +117,19 @@ ATTACHPTR **mutt_gen_attach_list (BODY *m,
 #endif
 	)
     {
-      idx = mutt_gen_attach_list (m->parts, idx, idxlen, idxmax, level, compose);
+      idx = mutt_gen_attach_list (m->parts, m->type, idx, idxlen, idxmax, level, compose);
     }
     else
     {
       new = idx[(*idxlen)++] = (ATTACHPTR *) safe_calloc (1, sizeof (ATTACHPTR));
       new->content = m;
+      new->parent_type = parent_type;
       new->level = level;
 
       /* We don't support multipart messages in the compose menu yet */
       if (!compose && mutt_is_message_type(m->type, m->subtype))
       {
-	idx = mutt_gen_attach_list (m->parts, idx, idxlen, idxmax, level + 1, compose);
+	idx = mutt_gen_attach_list (m->parts, m->type, idx, idxlen, idxmax, level + 1, compose);
       }
     }
   }
@@ -139,15 +141,16 @@ ATTACHPTR **mutt_gen_attach_list (BODY *m,
 }
 
 /* %D = deleted flag
-   %d = description
-   %e = MIME content-transfer-encoding
-   %f = filename
-   %t = tagged flag
-   %m = major MIME type
-   %M = MIME subtype
-   %n = attachment number
-   %s = size
-   %u = unlink */
+ * %d = description
+ * %e = MIME content-transfer-encoding
+ * %f = filename
+ * %t = tagged flag
+ * %m = major MIME type
+ * %M = MIME subtype
+ * %n = attachment number
+ * %s = size
+ * %u = unlink 
+ */
 const char *mutt_attach_fmt (char *dest,
     size_t destlen,
     char op,
@@ -159,90 +162,149 @@ const char *mutt_attach_fmt (char *dest,
     format_flag flags)
 {
   char fmt[16];
+  char tmp[SHORT_STRING];
   ATTACHPTR *aptr = (ATTACHPTR *) data;
-
+  char charset[SHORT_STRING];
+  int optional = (flags & M_FORMAT_OPTIONAL);
+  size_t l;
+  
   switch (op)
   {
     case 'd':
-      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-      if (aptr->content->description)
+      if(!optional)
       {
-	snprintf (dest, destlen, fmt, aptr->content->description);
-	break;
-      }
-      if (mutt_is_message_type(aptr->content->type, aptr->content->subtype) &&
-	  MsgFmt && aptr->content->hdr)
-      {
-	char s[SHORT_STRING];
-	_mutt_make_string (s, sizeof (s), MsgFmt, NULL, aptr->content->hdr,
-	    M_FORMAT_FORCESUBJ | M_FORMAT_MAKEPRINT | M_FORMAT_ARROWCURSOR);
-	if (*s)
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	if (aptr->content->description)
 	{
-	  snprintf (dest, destlen, fmt, s);
+	  snprintf (dest, destlen, fmt, aptr->content->description);
+	  break;
+	}
+	if (mutt_is_message_type(aptr->content->type, aptr->content->subtype) &&
+	    MsgFmt && aptr->content->hdr)
+	{
+	  char s[SHORT_STRING];
+	  _mutt_make_string (s, sizeof (s), MsgFmt, NULL, aptr->content->hdr,
+			     M_FORMAT_FORCESUBJ | M_FORMAT_MAKEPRINT | M_FORMAT_ARROWCURSOR);
+	  if (*s)
+	  {
+	    snprintf (dest, destlen, fmt, s);
+	    break;
+	  }
+	}
+	if (!aptr->content->filename)
+	{
+	  snprintf (dest, destlen, fmt, "<no description>");
 	  break;
 	}
       }
-      if (!aptr->content->filename)
-      {
-	snprintf (dest, destlen, fmt, "<no description>");
-	break;
-      }
-      /* FALLS THROUGH TO 'f' */
+      else if(aptr->content->description || 
+	      (mutt_is_message_type (aptr->content->type, aptr->content->subtype)
+	      && MsgFmt && aptr->content->hdr))
+        break;
+    /* FALLS THROUGH TO 'f' */
     case 'f':
-      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-      if (aptr->content->filename && *aptr->content->filename == '/')
+      if(!optional)
       {
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	if (aptr->content->filename && *aptr->content->filename == '/')
+	{
 	  char path[_POSIX_PATH_MAX];
 	  
 	  strfcpy (path, aptr->content->filename, sizeof (path));
 	  mutt_pretty_mailbox (path);
 	  snprintf (dest, destlen, fmt, path);
-      }
-      else
+	}
+	else
 	  snprintf (dest, destlen, fmt, NONULL (aptr->content->filename));
+      }
+      else if(!aptr->content->filename)
+        optional = 0;
       break;
     case 'D':
-      snprintf (dest, destlen, "%c", aptr->content->deleted ? 'D' : ' ');
+      if(!optional)
+	snprintf (dest, destlen, "%c", aptr->content->deleted ? 'D' : ' ');
+      else if(!aptr->content->deleted)
+        optional = 0;
       break;
     case 'e':
-      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-      snprintf (dest, destlen, fmt, ENCODING (aptr->content->encoding));
+      if(!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, ENCODING (aptr->content->encoding));
+      }
       break;
     case 'm':
-      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-      snprintf (dest, destlen, fmt, TYPE (aptr->content));
+      if(!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, TYPE (aptr->content));
+      }
       break;
     case 'M':
-      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-      snprintf (dest, destlen, fmt, aptr->content->subtype);
+      if(!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, aptr->content->subtype);
+      } 
+      else if(!aptr->content->subtype)
+        optional = 0;
       break;
     case 'n':
-      snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
-      snprintf (dest, destlen, fmt, aptr->num + 1);
+      if(!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
+	snprintf (dest, destlen, fmt, aptr->num + 1);
+      }
       break;
     case 's':
       if (flags & M_FORMAT_STAT_FILE)
       {
-	  struct stat st;
-
-	  stat (aptr->content->filename, &st);
-	  mutt_pretty_size (dest, destlen, st.st_size);
+	struct stat st;
+	stat (aptr->content->filename, &st);
+	l = st.st_size;
       }
       else
-	  mutt_pretty_size (dest, destlen, aptr->content->length);
+        l = aptr->content->length;
+      
+      if(!optional)
+      {
+	mutt_pretty_size (tmp, sizeof(tmp), l);
+	snprintf (fmt, sizeof(fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, tmp);
+      }
+      else if (l == 0)
+        optional = 0;
+
       break;
     case 't':
-      snprintf (dest, destlen, "%c", aptr->content->tagged ? '*' : ' ');
+      if(!optional)
+        snprintf (dest, destlen, "%c", aptr->content->tagged ? '*' : ' ');
+      else if(!aptr->content->tagged)
+        optional = 0;
       break;
     case 'T':
-      snprintf (dest, destlen, "%s", NONULL (aptr->tree));
+      if(!optional)
+      {
+	snprintf (fmt, sizeof(fmt), "%%%ss", prefix);
+        snprintf (dest, destlen, fmt, NONULL (aptr->tree));
+      } 
+      else if (!aptr->tree)
+        optional = 0;
       break;
     case 'u':
-      snprintf (dest, destlen, "%c", aptr->content->unlink ? '-' : ' ');
+      if(!optional)
+        snprintf (dest, destlen, "%c", aptr->content->unlink ? '-' : ' ');
+      else if (!aptr->content->unlink)
+        optional = 0;
       break;
     default:
       *dest = 0;
   }
+  
+  if (optional)
+    mutt_FormatString (dest, destlen, ifstring, mutt_attach_fmt, data, 0);
+  else if (flags & M_FORMAT_OPTIONAL)
+    mutt_FormatString (dest, destlen, elsestring, mutt_attach_fmt, data, 0);
   return (src);
 }
 
@@ -262,7 +324,7 @@ int mutt_is_message_type (int type, const char *subtype)
     return 0;
 
   subtype = NONULL(subtype);
-  return (strcasecmp (subtype, "rfc822") == 0 || strcasecmp (subtype, "news") == 0);
+  return (mutt_strcasecmp (subtype, "rfc822") == 0 || mutt_strcasecmp (subtype, "news") == 0);
 }
 
 static int mutt_query_save_attachment (FILE *fp, BODY *body, HEADER *hdr)
@@ -494,8 +556,8 @@ static int can_print (BODY *top, int tag)
     {
       if (!rfc1524_mailcap_lookup (top, type, NULL, M_PRINT))
       {
-	if (strcasecmp ("text/plain", top->subtype) &&
-	    strcasecmp ("application/postscript", top->subtype))
+	if (mutt_strcasecmp ("text/plain", top->subtype) &&
+	    mutt_strcasecmp ("application/postscript", top->subtype))
 	{
 	  if (!mutt_can_decode (top))
 	  {
@@ -525,8 +587,8 @@ static void print_attachment_list (FILE *fp, int tag, BODY *top)
       snprintf (type, sizeof (type), "%s/%s", TYPE (top), top->subtype);
       if (!option (OPTATTACHSPLIT) && !rfc1524_mailcap_lookup (top, type, NULL, M_PRINT))
       {
-	if (!strcasecmp ("text/plain", top->subtype) ||
-	    !strcasecmp ("application/postscript", top->subtype))
+	if (!mutt_strcasecmp ("text/plain", top->subtype) ||
+	    !mutt_strcasecmp ("application/postscript", top->subtype))
 	  pipe_attachment (fp, top);
 	else if (mutt_can_decode (top))
 	{
@@ -845,7 +907,7 @@ void mutt_view_attachments (HEADER *hdr)
     cur = hdr->content;
   }
 
-  idx = mutt_gen_attach_list (cur, idx, &idxlen, &idxmax, 0, 0);
+  idx = mutt_gen_attach_list (cur, -1, idx, &idxlen, &idxmax, 0, 0);
 
   menu = mutt_new_menu ();
   menu->max = idxlen;
@@ -905,48 +967,53 @@ void mutt_view_attachments (HEADER *hdr)
 
       case OP_DELETE:
 
-       if (menu->max == 1)
-       {
-         mutt_message _("Only deletion of multipart attachments is supported.");
-       }
-       else
-       {
 #ifdef _PGPPATH
-         if (hdr->pgp)
-         {
-           mutt_message _(
-             "Deletion of attachments from PGP messages is unsupported.");
-         }
-         else
+        if (hdr->pgp)
+        {
+	  mutt_message _(
+	    "Deletion of attachments from PGP messages is unsupported.");
+	}
+        else
 #endif
-         {
-	   if (!menu->tagprefix)
-	   {
-	     idx[menu->current]->content->deleted = 1;
-	     if (option (OPTRESOLVE) && menu->current < menu->max - 1)
-	     {
-	       menu->current++;
-	       menu->redraw = REDRAW_MOTION_RESYNCH;
-	     }
-	     else
-	       menu->redraw = REDRAW_CURRENT;
-	   }
-	   else
-	   {
-	     int x;
+        {
+	  if (!menu->tagprefix)
+	  {
+	    if (idx[menu->current]->parent_type == TYPEMULTIPART)
+	    {
+	      idx[menu->current]->content->deleted = 1;
+	      if (option (OPTRESOLVE) && menu->current < menu->max - 1)
+	      {
+		menu->current++;
+		menu->redraw = REDRAW_MOTION_RESYNCH;
+	      }
+	      else
+		menu->redraw = REDRAW_CURRENT;
+	    }
+	    else
+	      mutt_message _(
+	        "Only deletion of multipart attachments is supported.");
+	  }
+	  else
+	  {
+	    int x;
 
-	     for (x = 0; x < menu->max; x++)
-	     {
-	       if (idx[x]->content->tagged)
-	       {
-		 idx[x]->content->deleted = 1;
-		 menu->redraw = REDRAW_INDEX;
-	       }
-	     }
-	   }
-         }
-       }
-       break;
+	    for (x = 0; x < menu->max; x++)
+	    {
+	      if (idx[x]->content->tagged)
+	      {
+		if (idx[x]->parent_type == TYPEMULTIPART)
+		{
+		  idx[x]->content->deleted = 1;
+		  menu->redraw = REDRAW_INDEX;
+		}
+		else
+		  mutt_message _(
+		    "Only deletion of multipart attachments is supported.");
+	      }
+	    }
+	  }
+	}
+        break;
 
       case OP_UNDELETE:
        if (!menu->tagprefix)
