@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: sendlib.c,v 1.30 1998/11/10 21:02:27 roessler Exp $";
+static const char rcsid[]="$Id: sendlib.c,v 1.33 1998/11/18 22:57:03 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -125,7 +125,7 @@ static void encode_quoted (FILE * fin, FILE *fout, int istext)
   while ((c = fgetc (fin)) != EOF)
   {
     /* Escape lines that begin with "the message separator". */
-    if (linelen == 5 && !strncmp ("From ", line, 5))
+    if (linelen == 5 && !mutt_strncmp ("From ", line, 5))
     {
       strfcpy (line, "=46rom ", sizeof (line));
       linelen = 7;
@@ -302,7 +302,7 @@ static void encode_base64 (FILE * fin, FILE *fout, int istext)
 {
   int ch, ch1 = EOF;
   
-  b64_num = 0;
+  b64_num = b64_linelen = 0;
   
   while((ch = fgetc(fin)) != EOF)
   {
@@ -391,7 +391,7 @@ int mutt_write_mime_header (BODY *a, FILE *f)
 
   if (a->parameter)
   {
-    len = 25 + strlen (a->subtype); /* approximate len. of content-type */
+    len = 25 + mutt_strlen (a->subtype); /* approximate len. of content-type */
 
     for(p = a->parameter; p; p = p->next)
     {
@@ -404,7 +404,7 @@ int mutt_write_mime_header (BODY *a, FILE *f)
       buffer[0] = 0;
       rfc822_cat (buffer, sizeof (buffer), p->value, MimeSpecials);
 
-      tmplen = strlen (buffer) + strlen (p->attribute) + 1;
+      tmplen = mutt_strlen (buffer) + mutt_strlen (p->attribute) + 1;
 
       if (len + tmplen + 2 > 76)
       {
@@ -494,7 +494,7 @@ int mutt_write_mime_body (BODY *a, FILE *f)
 
 #ifdef _PGPPATH
   /* This is pretty gross, but it's the best solution for now... */
-  if (a->type == TYPEAPPLICATION && strcmp (a->subtype, "pgp-encrypted") == 0)
+  if (a->type == TYPEAPPLICATION && mutt_strcmp (a->subtype, "pgp-encrypted") == 0)
   {
     fputs ("Version: 1\n", f);
     return 0;
@@ -535,16 +535,18 @@ int mutt_write_mime_body (BODY *a, FILE *f)
 }
 
 #define BOUNDARYLEN 16
-char *mutt_generate_boundary (void)
+void mutt_generate_boundary (PARAMETER **parm)
 {
-  char *rs = (char *)safe_malloc (BOUNDARYLEN + 1);
+  char rs[BOUNDARYLEN + 1];
   char *p = rs;
   int i;
 
   rs[BOUNDARYLEN] = 0;
-  for (i=0;i<BOUNDARYLEN;i++) *p++ = B64Chars[LRAND() % sizeof (B64Chars)];
+  for (i=0;i<BOUNDARYLEN;i++) 
+    *p++ = B64Chars[LRAND() % sizeof (B64Chars)];
   *p = 0;
-  return (rs);
+  
+  mutt_set_parameter ("boundary", rs, parm);
 }
 
 /* analyze the contents of a file to determine which MIME encoding to use */
@@ -667,7 +669,7 @@ static int lookup_mime_type (char *d, const char *s)
   *d = 0;
   cur_n = TYPEOTHER;
   cur_sze = 0;
-  szf = strlen (s);
+  szf = mutt_strlen (s);
 
   for (count = 0 ; count < 3 ; count++)
   {
@@ -711,9 +713,9 @@ static int lookup_mime_type (char *d, const char *s)
 	/* cycle through the file extensions */
 	while ((p = strtok (p, " \t\n")))
 	{
-	  sze = strlen (p);
+	  sze = mutt_strlen (p);
 	  if ((sze > cur_sze) && (szf >= sze) &&
-	      strcasecmp (s + szf - sze, p) == 0 &&
+	      mutt_strcasecmp (s + szf - sze, p) == 0 &&
 	      (szf == sze || s[szf - sze - 1] == '.'))
 	  {
 	    char *dc;
@@ -750,7 +752,7 @@ static char *set_text_charset (CONTENT *info)
 
   /* if charset is unknown assume low bytes are ascii compatible */
 
-  if ((Charset == NULL || strcasecmp (Charset, "us-ascii") == 0)
+  if ((Charset == NULL || mutt_strcasecmp (Charset, "us-ascii") == 0)
       && info->hibin)
     return ("unknown-8bit");
 
@@ -848,7 +850,7 @@ static void transform_to_7bit (BODY *a, FILE *fpin)
 
       transform_to_7bit (a->parts, fpin);
     } 
-    else if (a->type == TYPEMESSAGE && strcasecmp (a->subtype, "delivery-status"))
+    else if (a->type == TYPEMESSAGE && mutt_strcasecmp (a->subtype, "delivery-status"))
     {
       mutt_message_to_7bit (a, fpin);
     }
@@ -935,19 +937,7 @@ void mutt_update_encoding (BODY *a)
   mutt_stamp_attachment(a);
   
   if (a->type == TYPETEXT)
-  {
-    /* make sure the charset is valid */
-    if (a->parameter)
-      safe_free ((void **) &a->parameter->value);
-    else
-    {
-      a->parameter = mutt_new_parameter ();
-      a->parameter->attribute = safe_strdup ("charset");
-    }
-    a->parameter->value = safe_strdup (set_text_charset (info));
-  }
-
-
+    mutt_set_parameter ("charset", set_text_charset (info), &a->parameter);
 
 #ifdef _PGPPATH
   /* save the info in case this message is signed.  we will want to do Q-P
@@ -1077,9 +1067,8 @@ BODY *mutt_make_file_attach (const char *path)
        */
       att->type = TYPETEXT;
       att->subtype = safe_strdup ("plain");
-      att->parameter = mutt_new_parameter ();
-      att->parameter->attribute = safe_strdup ("charset");
-      att->parameter->value = safe_strdup (set_text_charset (info));
+      
+      mutt_set_parameter("charset", set_text_charset(info), &att->parameter);
     }
     else
     {
@@ -1131,9 +1120,7 @@ BODY *mutt_make_multipart (BODY *b)
   new->type = TYPEMULTIPART;
   new->subtype = safe_strdup ("mixed");
   new->encoding = get_toplevel_encoding (b);
-  new->parameter = mutt_new_parameter ();
-  new->parameter->attribute = safe_strdup ("boundary");
-  new->parameter->value = mutt_generate_boundary ();
+  mutt_generate_boundary(&new->parameter);
   new->use_disp = 0;  
   new->parts = b;
 
@@ -1190,7 +1177,7 @@ void mutt_write_address_list (ADDRESS *adr, FILE *fp, int linelen)
     adr->next = NULL;
     buf[0] = 0;
     rfc822_write_address (buf, sizeof (buf), adr);
-    len = strlen (buf);
+    len = mutt_strlen (buf);
     if (count && linelen + len > 74)
     {
       if (count)
@@ -1381,7 +1368,7 @@ static void encode_headers (LIST *h)
       *p++ = 0;
       SKIPWS (p);
       snprintf (tmp, sizeof (tmp), "%s: ", h->data);
-      len = strlen (tmp);
+      len = mutt_strlen (tmp);
       rfc2047_encode_string (tmp + len, sizeof (tmp) - len, (unsigned char *) p);
       safe_free ((void **) &h->data);
       h->data = safe_strdup (tmp);
@@ -1721,8 +1708,8 @@ mutt_invoke_sendmail (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc, /* recips */
    string. */
 char *mutt_append_string (char *a, const char *b)
 {
-  size_t la = strlen (a);
-  safe_realloc ((void **) &a, la + strlen (b) + 1);
+  size_t la = mutt_strlen (a);
+  safe_realloc ((void **) &a, la + mutt_strlen (b) + 1);
   strcpy (a + la, b);
   return (a);
 }
@@ -1751,7 +1738,7 @@ char *mutt_quote_string (const char *s)
   char *r, *pr;
   size_t rlen;
 
-  rlen = strlen (s) + 3;
+  rlen = mutt_strlen (s) + 3;
   pr = r = (char *) safe_malloc (rlen);
   *pr++ = '"';
   while (*s)
@@ -1868,7 +1855,7 @@ ADDRESS *mutt_remove_duplicates (ADDRESS *addr)
     tmp = top;
     do {
       if (addr->mailbox && tmp->mailbox &&
-	  !strcasecmp (addr->mailbox, tmp->mailbox))
+	  !mutt_strcasecmp (addr->mailbox, tmp->mailbox))
       {
 	/* duplicate address, just ignore it */
 	tmp = addr;
